﻿using System;
using Pdftools.Pdf;
using Pdftools.Pdf2Pdf;

namespace sig
{
    class Program
    {
        static void Main(string[] args)
        {
            Pdf2Pdf converter = new Pdf2Pdf();

            //エラー マスク
            converter.ConversionErrorMask =
                  (int)PDFConversionError.ePDFConversionErrorVisualDiff
                + (int)PDFConversionError.ePDFConversionErrorOCGRemoved
                + (int)PDFConversionError.ePDFConversionErrorTranspRemoved
                + (int)PDFConversionError.ePDFConversionErrorEFRemoved
                + (int)PDFConversionError.ePDFConversionErrorLinearization
                + (int)PDFConversionError.ePDFConversionErrorSigCrea;

            //リポート サマリー
            converter.ConvertAlways = true;
            converter.ReportDetails = true;
            converter.ReportSummary = true;
            converter.PostAnalyze = false;
            converter.Compliance = PDFCompliance.ePDFA3a;

            //電子署名
            converter.CertificateName = "Taro Yamada";
            converter.Issuer = "CA51-3";
            converter.SignatureSerialNumber = "10 a3";
            converter.SignatureReason = "Received";
            converter.SetSignatureRectangle(390, 613, 120, 52);

            //印影
            converter.SignatureImageFileName = "hanko.png";

            //タイムスタンプ
            converter.TimeStampURL = "http://tsa.trustss.jp/";

            //変換
            if (converter.Convert("Receipt2.pdf", null, "Receipt02.pdf", "Receipt02.log"))
            {
                switch (converter.ErrorCode)
                {
                    case PDFErrorCode.PDF_E_CONVERSION:
                        Console.WriteLine("変換処理でエラーが発生した");
                        break;
                    case PDFErrorCode.PDF_E_POSTANALYSIS:
                        Console.WriteLine("変換処理で解析エラーが発生した");
                        break;
                    case PDFErrorCode.PDF_E_CONFORMANCE:
                        Console.WriteLine("文書が要求された標準に準拠していない");
                        break;
                    case PDFErrorCode.SIG_CREA_E_CERT:
                        Console.WriteLine("証明書が見つからない");
                        break;
                    default:
                        break;
                }
            }
            else
            {
                Console.WriteLine("Analysis in PDF/A compliant or output file could not be created.");
                switch (converter.ErrorCode)
                {
                    case PDFErrorCode.PDF_E_FILEOPEN:
                        Console.WriteLine("ファイルを開けない");
                        break;
                    case PDFErrorCode.PDF_E_FILECREATE:
                        Console.WriteLine("ファイルを作成できない");
                        break;
                    case PDFErrorCode.PDF_E_STOPPED:
                        Console.WriteLine("解析が中止された");
                        break;
                    default:
                        Console.WriteLine("変換エラー");
                        break;
                }
            }
        }
    }
}
